@@ -479,6 +479,42 @@ class FeedTest(unittest.TestCase):
     self.assert_(new_feed.generator.text == 'gen')    
     self.assert_(new_feed.entry[0].author[0].name.text == 'entry author')
 
+  def testPreserveEntryOrder(self):
+    test_xml = (
+        '<feed xmlns="http://www.w3.org/2005/Atom">'
+          '<entry><id>0</id></entry>'
+          '<entry><id>1</id></entry>'
+          '<title>Testing Order</title>'
+          '<entry><id>2</id></entry>'
+          '<entry><id>3</id></entry>'
+          '<entry><id>4</id></entry>'
+          '<entry><id>5</id></entry>'
+          '<entry><id>6</id></entry>'
+          '<entry><id>7</id></entry>'
+          '<author/>'
+          '<entry><id>8</id></entry>'
+          '<id>feed_id</id>'
+          '<entry><id>9</id></entry>'
+        '</feed>')
+    feed = atom.FeedFromString(test_xml)
+    for i in xrange(10):
+      self.assert_(feed.entry[i].id.text == str(i))
+    feed = atom.FeedFromString(feed.ToString())
+    for i in xrange(10):
+      self.assert_(feed.entry[i].id.text == str(i))
+    temp = feed.entry[3]
+    feed.entry[3] = feed.entry[4]
+    feed.entry[4] = temp
+    self.assert_(feed.entry[2].id.text == '2')
+    self.assert_(feed.entry[3].id.text == '4')
+    self.assert_(feed.entry[4].id.text == '3')
+    self.assert_(feed.entry[5].id.text == '5')
+    feed = atom.FeedFromString(feed.ToString())
+    self.assert_(feed.entry[2].id.text == '2')
+    self.assert_(feed.entry[3].id.text == '4')
+    self.assert_(feed.entry[4].id.text == '3')
+    self.assert_(feed.entry[5].id.text == '5')
+
 
 class ContentEntryParentTest(unittest.TestCase):
   """The test accesses hidden methods in atom.FeedEntryParent"""
@@ -590,6 +626,38 @@ class UtfParsingTest(unittest.TestCase):
     self.assert_(atom_entry.title.type == u'\u03B1\u03BB\u03C6\u03B1'.encode('utf-8'))
     self.assert_(atom_entry.title.text == u'\u03B1\u03BB\u03C6\u03B1'.encode('utf-8'))
 
+    # Setting object members to unicode strings is supported even if 
+    # MEMBER_STRING_ENCODING is set 'utf-8' (should it be?)
+    atom_entry.title.type = u'\u03B1\u03BB\u03C6\u03B1'
+    xml = atom_entry.ToString()
+    self.assert_(u'\u03B1\u03BB\u03C6\u03B1'.encode('utf-8') in xml)
+
+    # Make sure that we can use plain text when MEMBER_STRING_ENCODING is utf8
+    atom_entry.title.type = "plain text"
+    atom_entry.title.text = "more text"
+    xml = atom_entry.ToString()
+    self.assert_("plain text" in xml)
+    self.assert_("more text" in xml)
+
+    # Test something else than utf-8
+    atom.MEMBER_STRING_ENCODING = 'iso8859_7'
+    atom_entry = atom.EntryFromString(self.test_xml)
+    self.assert_(atom_entry.title.type == u'\u03B1\u03BB\u03C6\u03B1'.encode('iso8859_7'))
+    self.assert_(atom_entry.title.text == u'\u03B1\u03BB\u03C6\u03B1'.encode('iso8859_7'))
+
+    # Test using unicode strings directly for object members
+    atom.MEMBER_STRING_ENCODING = unicode
+    atom_entry = atom.EntryFromString(self.test_xml)
+    self.assert_(atom_entry.title.type == u'\u03B1\u03BB\u03C6\u03B1')
+    self.assert_(atom_entry.title.text == u'\u03B1\u03BB\u03C6\u03B1')
+    
+    # Make sure that we can use plain text when MEMBER_STRING_ENCODING is unicode
+    atom_entry.title.type = "plain text"
+    atom_entry.title.text = "more text"
+    xml = atom_entry.ToString()
+    self.assert_("plain text" in xml)
+    self.assert_("more text" in xml)
+
   def testConvertExampleXML(self):
     try:
       entry = atom.CreateClassFromXMLString(atom.Entry, test_data.GBASE_STRING_ENCODING_ENTRY)
